---
title: Little Racoon 
author: wcn247
source: Flickr
url: https://www.flickr.com/photos/wcn247/26231747536/
---
 
# {{title}}

Uploaded to [{{source}}]({{url}}) by {{author}}.

## License
Attribution-NonCommercial-NoDerivs 2.0 Generic (CC BY-NC-ND 2.0) 
[Download]({{assets}}/Creative_Commons-Attribution_4_International.pdf) Creative Commons Attribution 4 International license.
